@@ -5,6 +5,13 @@ assert_is_architect <- function(severity = getOption("assertive.severity", "stop
   assert_engine(is_architect, severity = severity)        
 }
 
+#' @rdname is_r
+#' @export
+assert_is_emacs <- function(severity = getOption("assertive.severity", "stop"))
+{                                                         
+  assert_engine(is_emacs, severity = severity)        
+}
+
 #' @rdname is_r
 #' @export
 assert_is_revo_r <- function(severity = getOption("assertive.severity", "stop"))
@@ -40,3 +47,10 @@ assert_is_rstudio_server <- function(severity = getOption("assertive.severity",
   assert_engine(is_rstudio_server, severity = severity)        
 }
 
+#' @rdname is_r
+#' @export
+assert_is_visual_studio <- function(severity = getOption("assertive.severity", "stop"))
+{                                                         
+  assert_engine(is_visual_studio, severity = severity)        
+}
+
