@@ -114,6 +114,34 @@ assert_is_macos_sierra <- function(severity = getOption("assertive.severity", "s
   assert_engine(is_macos_sierra, severity = severity)
 }
 
+#' @rdname is_windows
+#' @export
+assert_is_macos_high_sierra <- function(severity = getOption("assertive.severity", "stop"))
+{
+  assert_engine(is_macos_high_sierra, severity = severity)
+}
+
+#' @rdname is_windows
+#' @export
+assert_is_macos_mojave <- function(severity = getOption("assertive.severity", "stop"))
+{
+  assert_engine(is_macos_mojave, severity = severity)
+}
+
+#' @rdname is_windows
+#' @export
+assert_is_macos_catalina <- function(severity = getOption("assertive.severity", "stop"))
+{
+  assert_engine(is_macos_catalina, severity = severity)
+}
+
+#' @rdname is_windows
+#' @export
+assert_is_macos_big_sur <- function(severity = getOption("assertive.severity", "stop"))
+{
+  assert_engine(is_macos_big_sur, severity = severity)
+}
+
 #' @rdname is_windows
 #' @export
 assert_is_solaris <- function(severity = getOption("assertive.severity", "stop"))
