@@ -1,13 +1,7 @@
 test_that(
   "test.r_has_capabilities.returns_true_if_r_has_capabilities",
   {
-   caps <- capabilities()
-## does not support those added after 2016
-    OK <- c("jpeg", "png", "tiff", "tcltk", "X11", "aqua", "http/ftp",
-	    "sockets", "libxml", "fifo", "cledit", "iconv", "NLS",
-	    "profmem", "cairo", "ICU", "long.double", "libcurl")
-    caps <- capabilities(caps)
-    caps <- caps[intersect(names(caps), OK)]
+    caps <- capabilities()
     fns <- paste(
       "r_has", 
       sub("[/.]", "_", tolower(names(caps))), 
@@ -38,3 +32,17 @@ test_that(
     }
   }
 )
+
+if(as.package_version(version) < "4.1.0") {
+  test_that(
+    "test.r_has_capabilities.returns_na_for_undeclared_capability", 
+    {
+      actual <- r_has_rprof_capability()
+      expect_equal(strip_attributes(actual), NA)
+      expect_equal(
+        cause(actual), 
+        noquote("Rprof capability is not declared for versions of R before 4.1.0.")
+      )
+    }
+  )
+}
\ No newline at end of file
